def marshal_dict_to_bash_env(var, value):
    out = ""

    if isinstance(value, str) or isinstance(value, int) or isinstance(value, float) or isinstance(value, bool):
        out = "{}={}".format(var.upper(), value)

    elif isinstance(value, list):
        out = '{}=( {} )'.format(var.upper(), ' '.join(["'{}'".format(v) for v in value]))

    elif isinstance(value, dict):
        for k, v in value.iteritems():
            prefix = '{}_{}'.format(var, k)
            out += marshal_dict_to_bash_env(prefix, v) + '\n'

    return out.strip()



import sys
import ssl

from github import Github

from blunix_toolkit import config

C = config.get()

user = C['github']['user']
pw = C['github']['pass']
org = C['github']['org']
g = Github(user, pw)
user = g.get_user()


def get_repos():
    while True:
        try:
            return user.get_repos()
        except (Exception, ):
            sys.stderr.write("Retrying...\n")
            sys.stderr.flush()


def get_repo_full_name(repo):
    while True:
        try:
            return repo.full_name
        except (Exception, ):
            sys.stderr.write("Retrying...\n")
            sys.stderr.flush()
